# Changelog

<!--next-version-placeholder-->

## v1.2.1 (2022-06-02)
### Fix
* Remove unused cors config ([#2](https://github.com/draganagrbic998/devops_event_service/issues/2)) ([`8f86b98`](https://github.com/draganagrbic998/devops_event_service/commit/8f86b980e036ed2f69c4caf36b5ac45b664d411e))

## v1.2.0 (2022-05-30)
### Feature
* Events feature ([#1](https://github.com/draganagrbic998/devops_event_service/issues/1)) ([`7b47a8e`](https://github.com/draganagrbic998/devops_event_service/commit/7b47a8ec84451cc93ebe9dac10929543fa924b43))

## v1.1.0 (2022-05-30)
### Feature
* Init event service ([`1ee8c5d`](https://github.com/draganagrbic998/devops_event_service/commit/1ee8c5d790b3805395a5390d4bffc009b0999732))
